.. :changelog:

History
-------

0.2 (2016-09-12)
---------------------
* Renamed to scibag to avoid name collisions


0.1.4 (2016-05-24)
---------------------

* Dropped wheel dependency (#2)
* fixed version numbers throughout the project (#3)
* marked package as "inactive" to prepare for the name transition

0.1.3 (2015-04-23)
---------------------

* Added jsonschema dependency

0.1.1 (2015-04-23)
---------------------

* Added tornado dependency

0.1.0 (2015-04-23)
---------------------

* First release on PyPI.
